==> geeklog-1.8.0-jp-extended-1.0.tar.gz: geeklog-1.8.0-jp-extended-1.0/plugins/spamx/language/ukrainian.php <==
<?php

/**
 * File: ukrainian.php
 * This is the Ukrainian language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2006 by Vitaliy Biliyenko
 * v.lokki@gmail.com
 * 
 * Licensed under GNU General Public License
 *
 * $Id: ukrainian.php,v 1.7 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>   ,   ',
    'inst2' => '             ',
    'inst3' => '  .</p><p>    ,    ,     , ',
    'inst4' => '   <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a>   . ',
    'inst5' => '   .',
    'submit' => '',
    'subthis' => '      Spam-X',
    'secbut' => '     RDF,      .',
    'sitename' => ' : ',
    'URL' => 'URL  Spam-X: ',
    'RDF' => 'RDF url: ',
    'impinst1a' => '    Spam-X comment Spam blocker         ',
    'impinst1b' => ' ,       . (    .)',
    'impinst2' => '      Gplugs/Spam-X   - ',
    'impinst2a' => ',     . (:      ,      ',
    'impinst2b' => '    .           .) ',
    'impinst2c' => 'ϳ ,     ,  []   ,   .',
    'impinst3' => '   : ( ,   ).',
    'availb' => '  ',
    'clickv' => '    ',
    'clicki' => '    ',
    'ok' => 'OK',
    'rsscreated' => ' RSS ',
    'add1' => ' ',
    'add2' => '   ',
    'add3' => '  .',
    'adminc' => ' :',
    'mblack' => '̳  :',
    'rlinks' => ' :',
    'e3' => '      Geeklog,  :',
    'addcen' => '  ',
    'addentry' => ' ',
    'e1' => '  ,  .',
    'e2' => '  ,       .        Perl (Perl Regular Expressions).',
    'pblack' => '   Spam-X',
    'conmod' => '   Spam-X',
    'acmod' => ' 䳿 Spam-X',
    'exmod' => '  Spam-X',
    'actmod' => ' ',
    'avmod' => ' ',
    'coninst' => '<hr' . XHTML . '>  ,   ,   ,   .<br' . XHTML . '>     .',
    'fsc' => '  Spam- ',
    'fsc1' => '   ',
    'fsc2' => '  IP- ',
    'uMTlist' => ' MT-Blacklist',
    'uMTlist2' => ':  ',
    'uMTlist3' => '    ',
    'entries' => ' .',
    'uPlist' => '   ',
    'entriesadded' => ' ',
    'entriesdeleted' => ' ',
    'viewlog' => '  Spam-X',
    'clearlog' => ' ',
    'logcleared' => '- - Spam-X ',
    'plugin' => '',
    'access_denied' => ' ',
    'access_denied_msg' => '       .     IP- .',
    'admin' => ' ',
    'install_header' => '/ ',
    'installed' => ' ',
    'uninstalled' => '  ',
    'install_success' => ' ',
    'install_failed' => '  --  error.log  .',
    'uninstall_msg' => '  ',
    'install' => '',
    'uninstall' => '',
    'warning' => '!    ',
    'enabled' => '   .',
    'readme' => '!      ',
    'installdoc' => '  Install.',
    'spamdeleted' => ' Spam-',
    'foundspam' => '  Spam- ',
    'foundspam2' => '   ',
    'foundspam3' => '  IP- ',
    'deletespam' => ' Spam',
    'numtocheck' => 'ʳ   ',
    'note1' => '<p>:      ,    ',
    'note2' => '    Spam-X   .  <ul><li>     ',
    'note3' => '  -       .</li><li> ',
    'note4' => '    Spam-X     .</li></ul><p> ',
    'note5' => '     --     ',
    'note6' => '  .</p>',
    'masshead' => '<hr' . XHTML . '><h1 align="center">  Spam-</h1>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">  -</h1>',
    'comdel' => '  .',
    'initial_Pimport' => '<p>  "',
    'initial_import' => '  MT-Blacklist',
    'import_success' => '<p>  %d   .',
    'import_failure' => '<p><strong>:</strong>   .',
    'allow_url_fopen' => '<p>,         (<code>allow_url_fopen</code>   off). -,      URL      "data"  Geeklog, <tt>%s</tt>,    :',
    'documentation' => '  Spam-X',
    'emailmsg' => " -    \"%s\"\nUID : \"%s\"\n\n:\"%s\"",
    'emailsubject' => '-  %s',
    'ipblack' => '  IP Spam-X',
    'ipofurlblack' => '  IP  URL Spam-X',
    'headerblack' => '  HTTP- Spam-X',
    'headers' => ' :',
    'stats_headline' => ' Spam-X',
    'stats_page_title' => ' ',
    'stats_entries' => '',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => '  ',
    'stats_ip' => ' IP-',
    'stats_ipofurl' => '  IP  URL',
    'stats_header' => 'HTTP-',
    'stats_deleted' => ',   ',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => '  SLV'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = ' ,    .';
$PLG_spamx_MESSAGE8 = ' .    .';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>

==> geeklog-2.1.0-jp-extended-1.0.tar.gz: geeklog-2.1.0-jp-extended-1.0/plugins/spamx/language/ukrainian.php <==
<?php

/**
 * File: ukrainian.php
 * This is the Ukrainian language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2006 by Vitaliy Biliyenko
 * v.lokki@gmail.com
 * 
 * Licensed under GNU General Public License
 *
 * $Id: ukrainian.php,v 1.7 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>   ,   ',
    'inst2' => '             ',
    'inst3' => '  .</p><p>    ,    ,     , ',
    'inst4' => '   <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a>   . ',
    'inst5' => '   .',
    'submit' => '',
    'subthis' => '      Spam-X',
    'secbut' => '     RDF,      .',
    'sitename' => ' : ',
    'URL' => 'URL  Spam-X: ',
    'RDF' => 'RDF url: ',
    'impinst1a' => '    Spam-X comment Spam blocker         ',
    'impinst1b' => ' ,       . (    .)',
    'impinst2' => '      Gplugs/Spam-X   - ',
    'impinst2a' => ',     . (:      ,      ',
    'impinst2b' => '    .           .) ',
    'impinst2c' => 'ϳ ,     ,  []   ,   .',
    'impinst3' => '   : ( ,   ).',
    'availb' => '  ',
    'clickv' => '    ',
    'clicki' => '    ',
    'ok' => 'OK',
    'rsscreated' => ' RSS ',
    'add1' => ' ',
    'add2' => '   ',
    'add3' => '  .',
    'adminc' => ' :',
    'mblack' => '̳  :',
    'rlinks' => ' :',
    'e3' => '      Geeklog,  :',
    'addcen' => '  ',
    'addentry' => ' ',
    'e1' => '  ,  .',
    'e2' => '  ,       .        Perl (Perl Regular Expressions).',
    'pblack' => '   Spam-X',
    'sfseblack' => 'Spam-X SFS Email Blacklist',
    'conmod' => '   Spam-X',
    'acmod' => ' 䳿 Spam-X',
    'exmod' => '  Spam-X',
    'actmod' => ' ',
    'avmod' => ' ',
    'coninst' => '<hr' . XHTML . '>  ,   ,   ,   .<br' . XHTML . '>     .',
    'fsc' => '  Spam- ',
    'fsc1' => '   ',
    'fsc2' => '  IP- ',
    'uMTlist' => ' MT-Blacklist',
    'uMTlist2' => ':  ',
    'uMTlist3' => '    ',
    'entries' => ' .',
    'uPlist' => '   ',
    'entriesadded' => ' ',
    'entriesdeleted' => ' ',
    'viewlog' => '  Spam-X',
    'clearlog' => ' ',
    'logcleared' => '- - Spam-X ',
    'plugin' => '',
    'action' => 'Action',
    'access_denied' => ' ',
    'access_denied_msg' => '       .     IP- .',
    'admin' => ' ',
    'install_header' => '/ ',
    'installed' => ' ',
    'uninstalled' => '  ',
    'install_success' => ' ',
    'install_failed' => '  --  error.log  .',
    'uninstall_msg' => '  ',
    'install' => '',
    'uninstall' => '',
    'warning' => '!    ',
    'enabled' => '   .',
    'readme' => '!      ',
    'installdoc' => '  Install.',
    'spamdeleted' => ' Spam-',
    'foundspam' => '  Spam- ',
    'foundspam2' => '   ',
    'foundspam3' => '  IP- ',
    'deletespam' => ' Spam',
    'numtocheck' => 'ʳ   ',
    'note1' => '<p>:      ,    ',
    'note2' => '    Spam-X   .  <ul><li>     ',
    'note3' => '  -       .</li><li> ',
    'note4' => '    Spam-X     .</li></ul><p> ',
    'note5' => '     --     ',
    'note6' => '  .</p>',
    'masshead' => '<hr' . XHTML . '><h1 align="center">  Spam-</h1>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">  -</h1>',
    'comdel' => '  .',
    'initial_Pimport' => '<p>  "',
    'initial_import' => '  MT-Blacklist',
    'import_success' => '<p>  %d   .',
    'import_failure' => '<p><strong>:</strong>   .',
    'allow_url_fopen' => '<p>,         (<code>allow_url_fopen</code>   off). -,      URL      "data"  Geeklog, <tt>%s</tt>,    :',
    'documentation' => '  Spam-X',
    'emailmsg' => " -    \"%s\"\nUID : \"%s\"\n\n:\"%s\"",
    'emailsubject' => '-  %s',
    'ipblack' => '  IP Spam-X',
    'ipofurlblack' => '  IP  URL Spam-X',
    'headerblack' => '  HTTP- Spam-X',
    'headers' => ' :',
    'edit' => 'Edit',
    'view' => 'View',
    'value' => 'Value',
    'counter' => 'Counter',
    'stats_headline' => ' Spam-X',
    'stats_page_title' => ' ',
    'stats_entries' => '',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => '  ',
    'stats_ip' => ' IP-',
    'stats_ipofurl' => '  IP  URL',
    'stats_header' => 'HTTP-',
    'stats_deleted' => ',   ',
    'invalid_email_or_ip' => 'Invalid e-mail address or IP address has been blocked.',
    'email_ip_spam' => '%s or %s attempted to register but was considered a spammer.',
    'edit_personal_blacklist' => 'Edit Personal Blacklist',
    'mass_delete_spam_comments' => 'Mass Delete Spam Comments',
    'mass_delete_trackback_spam' => 'Mass Delete Trackback Spam',
    'edit_http_header_blacklist' => 'Edit HTTP Header Blacklist',
    'edit_ip_blacklist' => 'Edit IP Blacklist',
    'edit_ip_url_blacklist' => 'Edit IP of URL Blacklist',
    'edit_sfs_blacklist' => 'Edit SFS Email Blacklist',
    'edit_slv_whitelist' => 'Edit SLV Whitelist',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => '  SLV'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = ' ,    .';
$PLG_spamx_MESSAGE8 = ' .    .';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout',
    'max_age' => 'Max Age of Records',
    'records_delete' => 'Record Types to Delete',
    'sfs_enabled' => 'Enable SFS',
    'sfs_confidence' => 'Confidence Threshold',
    'snl_enabled' => 'Enable SNL',
    'snl_num_links' => 'Number of links'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings',
    'tab_modules' => 'Modules'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings',
    'fs_sfs' => 'Stop Forum Spam (SFS)',
    'fs_snl' => 'Spam Number of Links (SNL)'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>
